==> haskell-hastache-0.6.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hastache/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-977f1472f327db14442192a6e810281b
key: hasta_K8HO9vFW6ivBRJmMruFE2w
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/hastache-0.6.1
hs-libraries: HShastache-0.6.1-K8HO9vFW6ivBRJmMruFE2w
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ieee754-0.7.6-8a16b174e206384f3f621aa79d33ab8f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hastache-0.6.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-hastache/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-98cda3164df6aeeec7ce348b687c9c91
key: hasta_493qV9lVYIr24sveFVz7b4
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/hastache-0.6.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/hastache-0.6.1
hs-libraries: HShastache-0.6.1-493qV9lVYIr24sveFVz7b4
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    ieee754-0.7.6-8a16b174e206384f3f621aa79d33ab8f
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
